# IfcOpenShell - IFC toolkit and geometry engine
# Copyright (C) 2021 Dion Moult <dion@thinkmoult.com>
#
# This file is part of IfcOpenShell.
#
# IfcOpenShell is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# IfcOpenShell is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with IfcOpenShell.  If not, see <http://www.gnu.org/licenses/>.


class Usecase:
    def __init__(self, file):
        """Remove georeferencing data

        All georeferencing parameters such as projected CRS and map conversion
        data will be lost.

        :return: None
        :rtype: None

        Example:

            ifcopenshell.api.run("georeference.add_georeferencing", model)
            # Let's change our mind
            ifcopenshell.api.run("georeference.remove_georeferencing", model)
        """
        self.file = file

    def execute(self):
        map_conversion = self.file.by_type("IfcMapConversion")[0]
        projected_crs = self.file.by_type("IfcProjectedCRS")[0]
        if projected_crs.MapUnit and len(self.file.get_inverse(projected_crs.MapUnit)) == 1:
            # TODO: go deeper for conversion units
            self.file.remove(projected_crs.MapUnit)
        self.file.remove(projected_crs)
        self.file.remove(map_conversion)
